//***************************************************************
//				File:  ParameterDialog.java
//				Created by Mark Hoefer
//              Made Java 1.1 compliant by Chris Anderson
//
//              Reset sizing to include Parameter
//              List name CRA 3/26/98
//
//				(C) UCLA 1997
//***************************************************************
package cam.visuals.dialogs;

import java.awt.*;
import cam.dataxchg.ParameterList;
import java.util.Vector;

/**
A dialog which prompts the user for values of each item in
the ParameterList.  After clicking "OK" or "Apply" the values
are stored in the original ParameterList and a WINDOW_CLOSED event
is dispatched. One can catch this event by having the invoking class be
a listener.
@author Mark Hoefer, Chris Anderson
@version Oct. 30, 1998
*/

public class ParameterDialog extends Dialog
{
	java.awt.Button ApplyButton;
	java.awt.Button OKButton;
	java.awt.Button CancelButton;

	ParameterList parameters;
	Vector textfields; // holds the values for the parameters
	String exitState;
//
// Placement parameters
//
	int pady 				= 12;		// vertical distance between parameterlines
	int padx 				=  5;		// horizontal distance between elements of parameter line
	int numTextColumns	    =  8;		// the number of columns in the textbox; set higher for more digits
    int fontSizeUsed        = 14;
    int componentHeight     = 28;
    boolean ModalFlag       = true;
    int OKcolor             = 1220673;
    int CancelColor         = 14491204;
    int ApplyColor          = OKcolor;
    int BackgroundColor     = 9084855;
/**
Creates a dialog for the input parameter list. 
@param parent the parent frame
@param params the target ParameterList
@param ModalFlag specifies if the dialog is to be modal or non-modal
*/
    public ParameterDialog(Frame parent, cam.dataxchg.ParameterList params, boolean ModalFlag)
    {
        super(parent,ModalFlag);
        parameters = params;
		textfields = new Vector();
		layoutComponents();

	    //REGISTER_LISTENERS

	    SymWindow aSymWindow = new SymWindow();
		this.addWindowListener(aSymWindow);
	    SymAction lSymAction = new SymAction();
		ApplyButton.addActionListener(lSymAction);
		OKButton.addActionListener(lSymAction);
		CancelButton.addActionListener(lSymAction);
    }

	public void addNotify()
	{
  	    // Record the size of the window prior to calling parents addNotify.
	    Dimension d = getSize();

		super.addNotify();

		if (fComponentsAdjusted) return;

		// Adjust components according to the insets
		setSize(insets().left + insets().right + d.width, insets().top + insets().bottom + d.height);
		Component components[] = getComponents();
		for (int i = 0; i < components.length; i++)
		{
			Point p = components[i].getLocation();
			p.translate(insets().left, insets().top);
			components[i].setLocation(p);
		}

		fComponentsAdjusted = true;
	}

// Used for addNotify check.
	boolean fComponentsAdjusted = false;

//
// Lays out the components using the placement parameters
//
void layoutComponents()
{
//
// Clear old stuff
//
    removeAll();
    textfields.removeAllElements();
    //
    // Add new stuff
    //
    int num = parameters.getItemCount();
    setLayout(null);
    setVisible(false);

    addNotify();
    setFont(new Font("TimesRoman", Font.PLAIN, fontSizeUsed));
    Graphics g = getGraphics();
    FontMetrics fm = g.getFontMetrics(g.getFont());
    //
    // Find maximum parameter string length
    //
    String smax = "";
    String s = "";
    for(int i=1;i<=num;i++)
    {
        s = parameters.getItemName(i)+":";
        if(s.length() > smax.length())
        smax = s;
    }
    int strWidth    = fm.stringWidth("G")*smax.length();
    int compHeight  = componentHeight; // 3*fm.getHeight()/2;
    int textWidth   = numTextColumns*fm.stringWidth("G");
    int buttonWidth = 10+fm.stringWidth("Cancel");
    int titleWidth  = fm.stringWidth("G")*(parameters.getListName() + "  ").length();


    setTitle(parameters.getListName());
    //
    // Layout components
    //
    int width = Math.max(insets().left+insets().right+3*padx+
                    textWidth+strWidth,
                    insets().left+insets().right+3*buttonWidth+4*padx);
    width = Math.max(insets().left+insets().right+3*padx+
                    titleWidth, width);

    setSize(width,insets().top+insets().bottom+(num+3)*pady+(num+1)*compHeight);
    setBackground(new Color(BackgroundColor));

    TextField T;
    for(int i=1;i<=num;i++)
    {
        Label L = new Label(parameters.getItemName(i)+":");
        L.setBounds(insets().left+padx,insets().top+pady*i+(i-1)*compHeight,
             strWidth, compHeight);
        add(L);
        T = new TextField(numTextColumns);
        T.setText(parameters.getItemValueAsString(i));
        T.setBounds(insets().left+2*padx+strWidth,insets().top+pady*i+
             (i-1)*compHeight,textWidth,compHeight);
        textfields.addElement(T);
        add(T);
    }
    OKButton = new Button("OK");
    OKButton.setBounds(getSize().width/2-buttonWidth/2,
                  insets().top+(num+1)*pady+num*compHeight,
                    buttonWidth, compHeight);
    OKButton.setBackground(new Color(OKcolor));
    add(OKButton);

    ApplyButton = new Button("Apply");
    if(!ModalFlag)
    {
    ApplyButton.setBounds(getSize().width/2-3*buttonWidth/2-padx,
                  insets().top+(num+1)*pady+num*compHeight,
                  buttonWidth, compHeight);
    ApplyButton.setBackground(new Color(ApplyColor));
    add(ApplyButton);
    }
    CancelButton = new Button("Cancel");
    CancelButton.setBounds(getSize().width/2+buttonWidth/2+padx,
                    insets().top+(num+1)*pady+num*compHeight,
                      buttonWidth, compHeight);
    CancelButton.setBackground(new Color(CancelColor));
    add(CancelButton);

    setResizable(false);

    if(g!=null) g.dispose();
    }

//
// Mutator methods, call layoutComponents() to show updates
//

    void setPadX(int padX){ padx = padX; }
    void setPadY(int padY){ pady = padY; }
    void setNumTextColumns(int numText){ numTextColumns = numText; }
    void setFontSize(int fSize){fontSizeUsed = fSize;}

	public synchronized void show()
	{
		Rectangle bounds = getParent().bounds();
		Rectangle abounds = bounds();

		move(bounds.x + (bounds.width - abounds.width)/ 2,
			 bounds.y + (bounds.height - abounds.height)/2);

		super.show();
	}

	class SymWindow extends java.awt.event.WindowAdapter
	{
		public void windowClosing(java.awt.event.WindowEvent event)
		{
			Object object = event.getSource();
			if (object == ParameterDialog.this)
				ParameterDialog_WindowClosing(event);
		}
	}

	void ParameterDialog_WindowClosing(java.awt.event.WindowEvent event)
	{
	    exitState = "Cancel";
		dispose();
	}


	class SymAction implements java.awt.event.ActionListener
	{
		public void actionPerformed(java.awt.event.ActionEvent event)
		{
			Object object = event.getSource();
			if (object == ApplyButton)
				ApplyButton_Action(event);
			else if (object == OKButton)
				OKButton_Action(event);
			else if (object == CancelButton)
				CancelButton_Action(event);
		}
	}

	void ApplyButton_Action(java.awt.event.ActionEvent event)
	{
       //
       // Cycle through all the TextFields and set
       // the ParameterList
       //
           for(int i=0;i<textfields.size();i++)
           {
           TextField T = (TextField)textfields.elementAt(i);
           String value = T.getText();
           String Type = parameters.getItemType(i+1);
            if(Type.equals("java.lang.Boolean"))
            {
            parameters.setBoolean(i+1,
            Boolean.valueOf(value).booleanValue());
            }
            else if(Type.equals("java.lang.Character"))
            {
            parameters.setChar(i+1,value.charAt(0));
            }
            else if(Type.equals("java.lang.String"))
            {
            parameters.setString(i+1,value);
            }
            else if(Type.equals("java.lang.Integer"))
            {
            parameters.setInt(i+1,Integer.parseInt(value));
              }
            else if(Type.equals("java.lang.Long"))
            {
            parameters.setLong(i+1,Long.parseLong(value));
            }
            else if(Type.equals("java.lang.Float"))
            {
            parameters.setFloat(i+1,Float.valueOf(value).floatValue());
            }
            else if(Type.equals("java.lang.Double"))
            {
            parameters.setDouble(i+1,Double.valueOf(value).doubleValue());
            }
           } // end of for loop
           exitState = "Apply";
           java.awt.event.WindowEvent ev
           = new java.awt.event.WindowEvent(this, java.awt.event.WindowEvent.WINDOW_CLOSED);
           dispatchEvent(ev);
	}

	void OKButton_Action(java.awt.event.ActionEvent event)
	{
       // Cycle through all the TextFields and set
       // the ParameterList
       //
           int i;
           TextField T;
           String value;
           String Type;
           for(i=0;i<textfields.size();i++)
           {
           T     = (TextField)textfields.elementAt(i);
           value = T.getText();
           Type  = parameters.getItemType(i+1);
           if(Type.equals("java.lang.Boolean"))
            {
            parameters.setBoolean(i+1,
            Boolean.valueOf(value).booleanValue());
            }
            else if(Type.equals("java.lang.Character"))
            {
            parameters.setChar(i+1,value.charAt(0));
            }
            else if(Type.equals("java.lang.String"))
            {
            parameters.setString(i+1,value);
            }
            else if(Type.equals("java.lang.Integer"))
            {
            parameters.setInt(i+1,Integer.parseInt(value));
              }
            else if(Type.equals("java.lang.Long"))
            {
            parameters.setLong(i+1,Long.parseLong(value));
            }
            else if(Type.equals("java.lang.Float"))
            {
            parameters.setFloat(i+1,Float.valueOf(value).floatValue());
            }
            else if(Type.equals("java.lang.Double"))
            {
            parameters.setDouble(i+1,Double.valueOf(value).doubleValue());
            }
           } // end of for loop
           exitState = "OK";
           dispose();
	}

	void CancelButton_Action(java.awt.event.ActionEvent event)
	{
		exitState = "Cancel";
		dispose();
	}
/**
Returns exit state --- either "OK" or "Cancel".
*/
	public String getExitState(){return exitState;}
}
