package cam.visuals.plots;
//***************************************************************
//				File    :  GetBoundsDialog.java
//				Creator :  Mark Hoefer
//
//              Modifications:
//              10/18/98 - Chris Anderson -
//              Migration to Java 1.1 event model + bug fixes
//
//				(C) UCLA 1997,1998
//***************************************************************

import java.awt.*;

/**
 * A dialog for gathering the bounding rectangle
 * information for the PlotFrame class
**/

public class GetBoundsDialog extends Dialog {

	PlotFrame pFrame;
	TextField textXMin, textYMin, textXMax, textYMax;
	NumberToString NtoS;

	public GetBoundsDialog(PlotFrame parent) {
		super((Frame)parent, false);
		
		NtoS = new NumberToString();
		pFrame = parent;
		setTitle("Bounding Coordinates");
		setResizable(false);
		setLayout(new GridLayout(5,1));
		Panel p1 = new Panel();
		Panel p2 = new Panel();
		Panel p3 = new Panel();
		Panel p4 = new Panel();
		Panel p5 = new Panel();
		p1.add(new Label("Minimum X:"));
		textXMin = new TextField(10);
		textXMin.setText(NtoS.toString(pFrame.currentXMin));
		p1.add(textXMin);
	    p2.add(new Label("Maximum X:"));
		textXMax = new TextField(10);
		textXMax.setText(NtoS.toString(pFrame.currentXMax));
		p2.add(textXMax);
		p3.add(new Label("Minimum Y:"));
		textYMin = new TextField(10);
		textYMin.setText(NtoS.toString(pFrame.currentYMin));
		p3.add(textYMin);
		p4.add(new Label("Maximum Y:"));
		textYMax = new TextField(10);
		textYMax.setText(NtoS.toString(pFrame.currentYMax));
		p4.add(textYMax);
		OKButton = new Button("OK");
		p5.add(OKButton);
		ApplyButton = new Button("Apply");
		p5.add(ApplyButton);
		CancelButton = new Button("Cancel");
		p5.add(CancelButton);
		DefaultsButton = new Button("Defaults");
		p5.add(DefaultsButton);
		add(p1);
		add(p2);
		add(p3);
		add(p4);
		add(p5);		
		pack();
		
	    SymWindow aSymWindow = new SymWindow();
		this.addWindowListener(aSymWindow);
		
		SymAction lSymAction = new SymAction();
		OKButton.addActionListener(lSymAction);
		ApplyButton.addActionListener(lSymAction);
		CancelButton.addActionListener(lSymAction);
		DefaultsButton.addActionListener(lSymAction);
		show();
	}

	//{{DECLARE_CONTROLS
	java.awt.Button OKButton;
	java.awt.Button ApplyButton;
	java.awt.Button CancelButton;
	java.awt.Button DefaultsButton;
	//}}
	
   public synchronized void show() {
    	Rectangle bounds = getParent().bounds();
    	Rectangle abounds = bounds();

    	move(bounds.x + (bounds.width - abounds.width)/ 2,
    	     bounds.y + (bounds.height - abounds.height)/2);
    	super.show();

    }
	public void addNotify()
	{
  	    // Record the size of the window prior to calling parents addNotify.
	    Dimension d = getSize();

		super.addNotify();

		if (fComponentsAdjusted)
			return;

		// Adjust components according to the insets
		setSize(insets().left + insets().right + d.width, insets().top + insets().bottom + d.height);
		Component components[] = getComponents();
		for (int i = 0; i < components.length; i++)
		{
			Point p = components[i].getLocation();
			p.translate(insets().left, insets().top);
			components[i].setLocation(p);
		}
		fComponentsAdjusted = true;
	}

    // Used for addNotify check.
	boolean fComponentsAdjusted = false;
    
   	class SymWindow extends java.awt.event.WindowAdapter
	{
		public void windowClosing(java.awt.event.WindowEvent event)
		{
			Object object = event.getSource();
			if (object == GetBoundsDialog.this)
				GetBoundsDialog_WindowClosing(event);
		}
	}
	
	void GetBoundsDialog_WindowClosing(java.awt.event.WindowEvent event)
	{
		setVisible(false);	
		dispose();
	}
	
   class SymAction implements java.awt.event.ActionListener
	{
		public void actionPerformed(java.awt.event.ActionEvent event)
		{
			Object object = event.getSource();
			if (object == OKButton)
			OKButton_ActionPerformed(event);
			else if(object == ApplyButton)
			ApplyButton_ActionPerformed(event);
			else if(object == CancelButton)
			CancelButton_ActionPerformed(event);
			else if(object == DefaultsButton)
			DefaultsButton_ActionPerformed(event);
	    }
	}
	
	void OKButton_ActionPerformed(java.awt.event.ActionEvent event)
	{
	  double xmin,xmax,ymin,ymax;
      try
	  {
        xmin = (new Double(textXMin.getText())).doubleValue();
        ymin = (new Double(textYMin.getText())).doubleValue();
        xmax = (new Double(textXMax.getText())).doubleValue();
        ymax = (new Double(textYMax.getText())).doubleValue();
	  } 
	  // catch the error and wait for user to try again
	  catch(NumberFormatException e){return;} 
	  pFrame.setXYBounds(xmin,xmax,ymin,ymax);
	  (pFrame.getPlot()).rePlot();
	  setVisible(false);
	  dispose();
	}    
    void ApplyButton_ActionPerformed(java.awt.event.ActionEvent event)
	{
      double xmin,xmax,ymin,ymax;
      try
	  {
        xmin = (new Double(textXMin.getText())).doubleValue();
        ymin = (new Double(textYMin.getText())).doubleValue();
        xmax = (new Double(textXMax.getText())).doubleValue();
        ymax = (new Double(textYMax.getText())).doubleValue();
	  } 
	  // catch the error and wait for user to try again
	  catch(NumberFormatException e){System.out.println("Error");return;} 
	  pFrame.setXYBounds(xmin,xmax,ymin,ymax);
	  (pFrame.getPlot()).rePlot();
	} 
	void CancelButton_ActionPerformed(java.awt.event.ActionEvent event)
	{
		setVisible(false);
		dispose();
	} 
	void DefaultsButton_ActionPerformed(java.awt.event.ActionEvent event)
	{
    textXMax.setText(NtoS.toString(pFrame.xmax));
    textXMin.setText(NtoS.toString(pFrame.xmin));
    textYMax.setText(NtoS.toString(pFrame.ymax));
    textYMin.setText(NtoS.toString(pFrame.ymin));
	} 
}
