package cam.visuals.plots;
//***************************************************************
//				File:  GetTickDialog.java
//				Created by Mark Hoefer
//
//              Modifications:
//              10/18/98 - Chris Anderson -
//              Migration to Java 1.1 event model + bug fixes
//
//				(C) UCLA 1997
//***************************************************************
import java.awt.*;

/**
 * A dialog for gathering the tick mark scale in the
 * PlotFrame class
**/

public class GetTickDialog extends Dialog {

	PlotFrame pFrame;
	TextField textXScale, textYScale;

	public GetTickDialog(PlotFrame parent) {

		super((Frame)parent, false);
		pFrame = parent;
		NtoS   = new NumberToString();
		
		setTitle("Tick Mark Scale");
		setResizable(false);
		Panel p1 = new Panel();
		Panel p2 = new Panel();
		Panel p3 = new Panel();
		p1.add(new Label("X Tick Mark Scale:"));
		textXScale = new TextField(10);
		textXScale.setText(NtoS.toString(pFrame.plotCanvas.getXTickScale()));
		p1.add(textXScale);
		p2.add(new Label("Y Tick Mark Scale:"));
		textYScale = new TextField(10);
		textYScale.setText(NtoS.toString(pFrame.plotCanvas.getYTickScale()));
		p2.add(textYScale);
		OKButton = new java.awt.Button("OK");
		p3.add(OKButton);
		ApplyButton = new java.awt.Button("Apply");
		p3.add(ApplyButton);
		CancelButton = new java.awt.Button("Cancel");
		p3.add(CancelButton);
		DefaultButton = new java.awt.Button("Default");
		p3.add(DefaultButton);
		add("North",p1);
		add("Center",p2);
		add("South",p3);
		
		pack();
		show();
		
		//{{REGISTER_LISTENERS
		SymWindow aSymWindow = new SymWindow();
		this.addWindowListener(aSymWindow);
		SymAction lSymAction = new SymAction();
		CancelButton.addActionListener(lSymAction);
		OKButton.addActionListener(lSymAction);
		ApplyButton.addActionListener(lSymAction);
		DefaultButton.addActionListener(lSymAction);
		//}}
	}

	//{{DECLARE_CONTROLS
	java.awt.Button OKButton;
	java.awt.Button ApplyButton;
	java.awt.Button CancelButton;
	java.awt.Button DefaultButton;
	//}}
	
	
	NumberToString NtoS;
	
	
   public synchronized void show() {
    	Rectangle bounds = getParent().bounds();
    	Rectangle abounds = bounds();

    	move(bounds.x + (bounds.width - abounds.width)/ 2,
    	     bounds.y + (bounds.height - abounds.height)/2);
    	super.show();

    }
	public void addNotify()
	{
  	    // Record the size of the window prior to calling parents addNotify.
	    Dimension d = getSize();

		super.addNotify();

		if (fComponentsAdjusted)
			return;

		// Adjust components according to the insets
		setSize(insets().left + insets().right + d.width, insets().top + insets().bottom + d.height);
		Component components[] = getComponents();
		for (int i = 0; i < components.length; i++)
		{
			Point p = components[i].getLocation();
			p.translate(insets().left, insets().top);
			components[i].setLocation(p);
		}
		fComponentsAdjusted = true;
	}

    // Used for addNotify check.
	boolean fComponentsAdjusted = false;
	
	class SymWindow extends java.awt.event.WindowAdapter
	{
		public void windowClosing(java.awt.event.WindowEvent event)
		{
			Object object = event.getSource();
			if (object == GetTickDialog.this)
				GetTickDialog_WindowClosing(event);
		}
	}
	
	void GetTickDialog_WindowClosing(java.awt.event.WindowEvent event)
	{
		setVisible(false);	
		dispose();
	}
	
	
	class SymAction implements java.awt.event.ActionListener
	{
		public void actionPerformed(java.awt.event.ActionEvent event)
		{
			Object object = event.getSource();
			if (object == CancelButton)
				CancelButton_ActionPerformed(event);
			else if (object == OKButton)
				OKButton_ActionPerformed(event);
			else if (object == ApplyButton)
				ApplyButton_ActionPerformed(event);
			else if (object == DefaultButton)
				DefaultButton_ActionPerformed(event);
		}
	}
	
	
	void CancelButton_ActionPerformed(java.awt.event.ActionEvent event)
	{
        setVisible(false);
        dispose();
	}
	
	void OKButton_ActionPerformed(java.awt.event.ActionEvent event)
	{
        double xtick, ytick;
        try
        {
            xtick = (new Double(textXScale.getText())).doubleValue();
            ytick = (new Double(textYScale.getText())).doubleValue();
        } 
        // 	   		// catch the error and wait for user to try again
        catch(NumberFormatException e){return;} 
        pFrame.plotCanvas.setTickScale(xtick,ytick);
        (pFrame.getPlot()).rePlot();
        setVisible(false);
        dispose();
	}
	
	void ApplyButton_ActionPerformed(java.awt.event.ActionEvent event)
	{
        double xtick, ytick;
   		
        try
        {
            xtick = (new Double(textXScale.getText())).doubleValue();
            ytick = (new Double(textYScale.getText())).doubleValue();
        } 
        // 	   		// catch the error and wait for user to try again
        catch(NumberFormatException e){return;} 
        pFrame.plotCanvas.setTickScale(xtick,ytick);
        (pFrame.getPlot()).rePlot();
	}
	
	void DefaultButton_ActionPerformed(java.awt.event.ActionEvent event)
	{
    pFrame.plotCanvas.setAutoTickScaling(true);
    textXScale.setText(NtoS.toString(pFrame.plotCanvas.getXTickScale()));
    textYScale.setText(NtoS.toString(pFrame.plotCanvas.getYTickScale()));
	}
	
}
