package cam.visuals.plots;
//***************************************************************
//				File    :  LegendDialog.java
//				Creator :  Mark Hoefer
//
//              Modifications :
//              10/18/98 - Chris Anderson -
//              Migration to Java 1.1 event model + bug fixes
//
//				(C) UCLA 1997,1998
//***************************************************************

import java.awt.*;

/**
 * Allows the user to view names, colors, and plot types
 * for plots in the PlotFrame
**/
public class LegendDialog extends Dialog
{
	PlotFrame pFrame;
	int pady = 5;
	int padx = 5;
	int maxNameLength;
	int compHeight;
	int lineLength = 40;
	
	Button closeButton;
	
	public LegendDialog(PlotFrame pf)
	{
		super((Frame)pf,false);
		pFrame = pf;
		
	//
	// Layout components
	//
		setLayout(null);
		addNotify();
		setFont(new Font("TimesRoman", Font.PLAIN, 12));
		Graphics g = getGraphics();
		FontMetrics fm = g.getFontMetrics(g.getFont());
		
		// Find maximum name length
		String[] allNames = pFrame.plotCanvas.getPlotNames();
		int numNames = allNames.length;
		maxNameLength = 0;
		int currentLength;
		for(int i=0;i<numNames;i++)
		{
			currentLength = fm.stringWidth(allNames[i]+":");
			if(currentLength > maxNameLength)
				maxNameLength = currentLength;
		}
		
		// Set the component height
		compHeight = 3*fm.getHeight()/2;
		
		resize(insets().left+insets().right+3*padx+maxNameLength+lineLength,
				 insets().top+insets().bottom+(numNames+1)*(compHeight+pady)+
				 pady);
		for(int i=0;i<numNames;i++)
		{
			Label L = new Label(allNames[i]+":");
			L.reshape(insets().left+padx,insets().top+(i+1)*pady+i*compHeight,
						 maxNameLength,compHeight);
			add(L);
		}
		int buttonWidth = fm.stringWidth("Close")+10;
		closeButton = new Button("Close");
		closeButton.reshape((size().width-buttonWidth)/2,
								  insets().top+numNames*(pady+compHeight)+pady,
								  buttonWidth,compHeight);
		add(closeButton);
		setTitle("Plot Legend");
		SymAction lSymAction = new SymAction();
		closeButton.addActionListener(lSymAction);
		SymWindow aSymWindow = new SymWindow();
		this.addWindowListener(aSymWindow);
		
		g.dispose();
	}
	
	public void paint(Graphics g)
	{
		// draw the samples of each plot
		FontMetrics fm    = g.getFontMetrics(g.getFont());
		String[] allNames = pFrame.plotCanvas.getPlotNames();
		
		for(int i=0;i<allNames.length;i++)
		{
			// draw a sample of each curve
			g.setColor(pFrame.plotCanvas.getPlotColor(allNames[i]));
			if(pFrame.plotCanvas.getPlotType(allNames[i]) == Plot.CURVE)
			{
				g.drawLine(2*padx+maxNameLength,
							  (i+1)*(compHeight+pady)+compHeight/2,
							  2*padx+maxNameLength+lineLength,
							  (i+1)*(compHeight+pady)+compHeight/2);
			}
			else if(pFrame.plotCanvas.getPlotType(allNames[i]) == Plot.POINTS)
			{
				int numPoints = 4;
				char[] ch = new char[1];
				ch[0] = pFrame.plotCanvas.getPlotChar(allNames[i]);
				for(int j=0;j<numPoints;j++)
					g.drawChars(ch,0,1,2*padx+maxNameLength+
									j*lineLength/numPoints,
									(i+1)*(compHeight+pady)+compHeight/2+
									fm.getAscent()/2);
			}
			else
			{
				int numPoints = 4;
				char[] ch = new char[1];
				ch[0] = pFrame.plotCanvas.getPlotChar(allNames[i]);
				for(int j=0;j<numPoints;j++)
					g.drawChars(ch,0,1,2*padx+maxNameLength+
									j*lineLength/numPoints,
									(i+1)*(compHeight+pady)+compHeight/2+
									fm.getAscent()/2);
				g.drawLine(2*padx+maxNameLength,
							  (i+1)*(compHeight+pady)+compHeight/2,
							  2*padx+maxNameLength+lineLength,
							  (i+1)*(compHeight+pady)+compHeight/2);
			}
		}
	}
	
   public synchronized void show() {
    	Rectangle bounds = getParent().bounds();
    	Rectangle abounds = bounds();

    	move(bounds.x + bounds.width - abounds.width,
    	     bounds.y + bounds.height - abounds.height);
    	super.show();
   }
   
	public void addNotify()
	{
  	    // Record the size of the window prior to calling parents addNotify.
	    Dimension d = getSize();

		super.addNotify();

		if (fComponentsAdjusted)
			return;

		// Adjust components according to the insets
		setSize(insets().left + insets().right + d.width, insets().top + insets().bottom + d.height);
		Component components[] = getComponents();
		for (int i = 0; i < components.length; i++)
		{
			Point p = components[i].getLocation();
			p.translate(insets().left, insets().top);
			components[i].setLocation(p);
		}
		fComponentsAdjusted = true;
	}

    // Used for addNotify check.
	boolean fComponentsAdjusted = false;
   
   
//
// When a plot is removed, layout labels again
//
   public void removePlot()
   {
   	// remove all the components and add them again
   	removeAll();
   
		Graphics g = getGraphics();
		FontMetrics fm = g.getFontMetrics(g.getFont());
		
		// Find maximum name length
		String[] allNames = pFrame.plotCanvas.getPlotNames();
		int numNames = allNames.length;
		maxNameLength = 0;
		int currentLength;
		for(int i=0;i<numNames;i++)
		{
			currentLength = fm.stringWidth(allNames[i]+":");
			if(currentLength > maxNameLength)
				maxNameLength = currentLength;
		}
		
		// Set the component height
		compHeight = 3*fm.getHeight()/2;
		
		resize(insets().left+insets().right+3*padx+maxNameLength+lineLength,
				 insets().top+insets().bottom+(numNames+1)*(compHeight+pady)+
				 pady);
		for(int i=0;i<numNames;i++)
		{
			Label L = new Label(allNames[i]+":");
			L.reshape(insets().left+padx,insets().top+(i+1)*pady+i*compHeight,
						 maxNameLength,compHeight);
			add(L);
		}
		int buttonWidth = fm.stringWidth("Close")+10;
		closeButton = new Button("Close");
		closeButton.reshape((size().width-buttonWidth)/2,
								  insets().top+numNames*(pady+compHeight)+pady,
								  buttonWidth,compHeight);
		add(closeButton);
		g.dispose();
		validate();
		repaint();
   }
   
   	class SymWindow extends java.awt.event.WindowAdapter
	{
		public void windowClosing(java.awt.event.WindowEvent event)
		{
			Object object = event.getSource();
			if (object == LegendDialog.this)
				LegendDialog_WindowClosing(event);
		}
	}
	
	void LegendDialog_WindowClosing(java.awt.event.WindowEvent event)
	{
		setVisible(false);	
		dispose();
	}
	
   class SymAction implements java.awt.event.ActionListener
	{
		public void actionPerformed(java.awt.event.ActionEvent event)
		{
			Object object = event.getSource();
			if (object == closeButton)
			closeButton_ActionPerformed(event);
	    }
	}
	void closeButton_ActionPerformed(java.awt.event.ActionEvent event)
	{
		setVisible(false);
		dispose();
	}    
}
