package cam.visuals.plots;
import java.io.*;
/**
A class that provides more conventional string formatting of
Java's standard numeric data types. The functionality
of this class is obtained by working with the output from the
Double class method toString().

@author Chris Anderson (C) UCLA 1998
@version Oct. 16, 1998
*/
public class NumberToString
{
public NumberToString(){};

/**
Sets the precision of the output to p. For floating point numbers
in scientific notation, this means the mantissa has p digits
past the decimal point.  For fixed point output, this means a
total of p digits.
*/
public void setPrecision(int p)
{precision = p;}

/**
Sets the output format to normalized floating point. The output
have the form D.XXXXXe&plusmn;ZZZ, where 
0 <FONT FACE="Symbol">&pound;</FONT> D 
<FONT FACE="Symbol">&pound;</FONT>
9, and the number of
digits in the mantissa past the decimal point (the number of X's)
is equal to the output precision.
*/
public void setScientific(boolean v)
{scientific = v;}

/**
Creates a string representation of an int value.
*/
public String toString(int d)
{
    if(scientific) return toString((double)d);
    return String.valueOf(d);
}

/**
Creates a string representation of a long value
*/
public String toString(long d)
{
    if(scientific) return toString((double)d);
    return String.valueOf(d);
}

/**
Creates a string representation of a float value
*/
public String toString(float d)
{return toString((double)d);}


/**
Creates a string representation of a double value
*/
public String toString(double d)
{
    //
    // obtain sign
    //
    char dSign;
    if(d >= 0){dSign = '+';}
    else      {dSign = '-'; d = -d;}
    //
    // decompose into a mantissa and an exponent
    //
    double expon    = 0.0;
    double mantissa = 0.0;
    if(d != 0.0)
    {
    expon    = (Math.log(d))/(Math.log(10));
    expon    = (Math.floor(expon));
    mantissa = d/(Math.pow(10.0,expon));
    }

    char eSign;
    if(expon >= 0){eSign = '+';}
    else          {eSign = '-';}
    //
    // Create an array of characters for the digits in the
    // mantissa using the output from the toString method of Double().
    //
    Double Mantissa = new Double(mantissa);
    int    k;
    char[] manChars = new char[25];
    String MantissaString = Mantissa.toString();

    manChars[0] = MantissaString.charAt(0);
    manChars[1] = MantissaString.charAt(2);

    for(k = 3; k < MantissaString.length(); k++)
    {manChars[k-1] = MantissaString.charAt(k);}

    for(k = MantissaString.length(); k < 26; k++)
    {manChars[k-1] = Character.forDigit(0,10);}

    int   ichar;
    double z = 0.0;
    double val;
    //
    // Create an array of characters for the digits for the exponent
    //
    char [] eChars = new char[3];
    int powr = (int)expon;
    if(powr < 0) powr = - powr;

    if(powr < 10)
    {
     eChars[0] = Character.forDigit(0,10);
     eChars[1] = Character.forDigit(powr,10);
    }
    else if(powr<= 99)
    {
     eChars[0] = Character.forDigit(powr/10,10);
     eChars[1] = Character.forDigit(powr - 10*(powr/10),10);
    }
    else
    {
     eChars[0] = Character.forDigit(powr/100,10);
     eChars[1] = Character.forDigit((powr - 100*(powr/100))/10,10);
     eChars[2] = Character.forDigit(powr - 10*(powr/10),10);
    }
//
//  Compose output
//
    String S = null;

    String SA = null;
    String SB = null;
    String SC = null;
    String SD = null;
    String SE = null;

    char [] zChars = new char[20];

    if(dSign == '+')
    {SA = String.valueOf(' ');}
    else
    {SA = String.valueOf(dSign);}

    if(scientific)
    {
       SB = new String(manChars,0,1);
       SC = new String(manChars,1,precision);
       SD = String.valueOf(eSign);
       if((int)expon <= 99) SE = new String(eChars,0,2);
       else SE = new String(eChars,0,3);
       S = new String(SA + SB + "." + SC + "e" + SD + SE);
    }
    else
    {
      if(expon >= 0)
      {
         SB = new String(manChars,0,(int)expon+1);
         SC = new String(manChars,(int)expon+1,precision);
         S = new String(SA + SB + "." + SC);
       }
       else
       {
         for(k = 0; k < -(int)expon-1; k++) zChars[k] = '0';
         SB = new String(zChars,0,-(int)expon-1);
         SC = new String(manChars,0,precision + (int)expon+1);
         S = new String(SA + "." + SB + SC);
       }
    }
    return S;
}

public static void main(String[] args)
{
    NumberToString N = new NumberToString();
    N.setScientific(true);
    N.setPrecision(4);
    System.out.println(N.toString(-0.0));
    System.out.println(N.toString(23450.00001043444));
    N.setPrecision(10);
    System.out.println(N.toString(23450.00001073444));
    N.setScientific(false);
    System.out.println(N.toString(23450.00001073444));
    N.setScientific(true);
    System.out.println(N.toString(2.0/3.0));
//
//  Pause command window
//
    BufferedReader d =
    new BufferedReader(new InputStreamReader(System.in));
    try{d.readLine();}catch(Exception e){};
}
//
private boolean scientific = true;
private int     precision  = 5;
//
}