package cam.visuals.plots;
//***************************************************************
//				File:  PlotData.java
//				Created by Mark Hoefer
//				(C) UCLA 1997
//***************************************************************

import java.awt.Color;

/**
Stores discrete data and 2-d plotting information
*/

public class PlotData
{
//***************************************************************
//                          DATA
//***************************************************************
	private double[] x;
	private double[] y;
	private Color color = Color.black;
	private char character = '*';
	private String name;
//
// The plot type
//
	private int plotType = Plot.CURVE;
//
//***************************************************************
//                          METHODS
//***************************************************************
//
// Constructor which uses default data for the character constant
// and the color
//
	PlotData(double[] xdata, double[] ydata, String plotName)
	{
		if(xdata.length != ydata.length)
		{
			System.err.println("The x and y arrays are of different length");
			return;
		}
		
		x = new double[xdata.length];
		y = new double[ydata.length];
		System.arraycopy(xdata,0,x,0,x.length);
		System.arraycopy(ydata,0,y,0,y.length);
		name = new String(plotName);
	}
	PlotData(double[] xdata, double[] ydata, Color c, char ch, 
				String plotName, int type)
	{
		if(type != Plot.CURVE && type != Plot.POINTS && Plot.CURVE_AND_POINTS != 2)
		{
			System.err.println("Not a valid plot type.");
			return;
		}
		if(xdata.length != ydata.length)
		{
			System.err.println("The x and y arrays are of different length");
			return;
		}
		
		x = new double[xdata.length];
		y = new double[ydata.length];
		System.arraycopy(xdata,0,x,0,x.length);
		System.arraycopy(ydata,0,y,0,y.length);
		color = c;
		character = ch;
		name = new String(plotName);
		plotType = type; 
	}
//
// Accessor Methods
//
	public double[] getXdata() { return x;}
	public double[] getYdata() { return y;}
	public Color getColor() 
	{
		return new Color(color.getRed(),color.getGreen(),color.getBlue());
	}
	public char getPointChar() { return character;}
	public String getPlotName() { return new String(name);}
	public int getPlotType() { return plotType;}
	public boolean isPlotName(String plotName)
	{
		return name.equals(plotName)? true: false;
	}
//
// Mutator Methods
//
	public void setData(double[] xdata, double[] ydata)
	{
		if(xdata.length != ydata.length)
		{
			System.err.println("The x and y arrays are of different length");
			return;
		}
		
		x = new double[xdata.length];
		y = new double[ydata.length];
		System.arraycopy(xdata,0,x,0,x.length);
		System.arraycopy(ydata,0,y,0,y.length);
	}
	public void setPlotType(int type)
	{ 
		if(type != Plot.CURVE && type != Plot.POINTS && Plot.CURVE_AND_POINTS != 2)
		{
			System.err.println("Not a valid plot type.");
			return;
		}
	
		plotType = type;
	}
	public void setColor(Color c) { color = c;}
	public void setPlotName(String plotName) {name = plotName;}
	public void setPlotChar(char ch) { character = ch;}
}