package cam.visuals.plots;
//***************************************************************
//				File    :  PlotInfoDialog.java
//				Creator :  Mark Hoefer
//              
//              Modifications : 
//              10/18/98 - Chris Anderson -
//              Migration to Java 1.1 event model + bug fixes
//
//				(C) UCLA 1997,1998
//***************************************************************

import java.awt.*;

/**
 * This Dialog allows the user to see and change various
 * characteristics of a plot: name, color, type, point char
 *
 * @see PlotFrame
**/
public class PlotInfoDialog extends Dialog {

	PlotFrame pFrame;
	String plotName;

/**
 * Constructs a PlotInfoDialog
 *
 * @param parent the PlotFrame from which this dialog is created
 * @param plotName the name of the plot to be viewed
**/
	public PlotInfoDialog(PlotFrame parent, String plotName) {

	    super((Frame)parent, false);
	    pFrame = parent;
	    this.plotName = new String(plotName);

		//{{INIT_CONTROLS
		setLayout(null);
		setVisible(false);
		setSize(243,237);
		setFont(new Font("TimesRoman", Font.PLAIN, 12));
		typeLabel = new java.awt.Label("Plot Type:");
		typeLabel.setBounds(31,80,64,24);
		add(typeLabel);
		typeChoice = new java.awt.Choice();
		typeChoice.addItem("Curve");
		typeChoice.addItem("Point");
		typeChoice.addItem("Curve and Point");
		try {
			typeChoice.select(0);
		}
		catch (IllegalArgumentException e) { }
		add(typeChoice);
		typeChoice.setBounds(95,80,105,23);
		colorChoice = new java.awt.Choice();
		colorChoice.addItem("black");
		colorChoice.addItem("blue");
		colorChoice.addItem("cyan");
		colorChoice.addItem("gray");
		colorChoice.addItem("green");
		colorChoice.addItem("magenta");
		colorChoice.addItem("orange");
		colorChoice.addItem("pink");
		colorChoice.addItem("red");
		colorChoice.addItem("yellow");
		try {
			colorChoice.select(0);
		}
		catch (IllegalArgumentException e) { }
		add(colorChoice);
		colorChoice.setBounds(95,48,105,23);
		colorLabel = new java.awt.Label("Color:");
		colorLabel.setBounds(31,48,64,24);
		add(colorLabel);
		charText = new java.awt.TextField();
		charText.setBounds(95,112,32,24);
		add(charText);
		charLabel = new java.awt.Label("Point Char:");
		charLabel.setBounds(31,112,64,24);
		add(charLabel);
		nameText = new java.awt.TextField();
		nameText.setBounds(95,16,137,24);
		add(nameText);
		nameLabel = new java.awt.Label("Plot Name:");
		nameLabel.setBounds(31,16,64,24);
		add(nameLabel);
		okButton = new java.awt.Button();
		okButton.setLabel("OK");
		okButton.setBounds(16,192,60,24);
		add(okButton);
		applyButton = new java.awt.Button();
		applyButton.setLabel("Apply");
		applyButton.setBounds(96,192,60,24);
		add(applyButton);
		cancelButton = new java.awt.Button();
		cancelButton.setLabel("Cancel");
		cancelButton.setBounds(168,192,60,24);
		add(cancelButton);
		removeButton = new java.awt.Button();
		removeButton.setLabel("Remove Plot");
		removeButton.setBounds(80,152,76,24);
		add(removeButton);
		setTitle("Plot Characteristics");
		//}}
	//
	// Set values for components
	//
		nameText.setText(plotName);
		charText.setText(String.valueOf(pFrame.plotCanvas.getPlotChar(plotName)));
		colorChoice.select(getColorText(pFrame.plotCanvas.getPlotColor(plotName)));
		typeChoice.select(getPlotTypeText());
		
		show();
	
		//{{REGISTER_LISTENERS
		SymWindow aSymWindow = new SymWindow();
		this.addWindowListener(aSymWindow);
		SymAction lSymAction = new SymAction();
		removeButton.addActionListener(lSymAction);
		okButton.addActionListener(lSymAction);
		applyButton.addActionListener(lSymAction);
		cancelButton.addActionListener(lSymAction);
		//}}
	}
	
	
    public void addNotify()
	{
  	    // Record the size of the window prior to calling parents addNotify.
	    Dimension d = getSize();

		super.addNotify();

		if (fComponentsAdjusted)
			return;

		// Adjust components according to the insets
		setSize(insets().left + insets().right + d.width, insets().top + insets().bottom + d.height);
		Component components[] = getComponents();
		for (int i = 0; i < components.length; i++)
		{
			Point p = components[i].getLocation();
			p.translate(insets().left, insets().top);
			components[i].setLocation(p);
		}
		fComponentsAdjusted = true;
	}

    // Used for addNotify check.
	boolean fComponentsAdjusted = false;

//
// Find the plot type and return it as a String, if not
// one from PlotData then return String "other"
//
	private String getPlotTypeText()
	{
		int type = pFrame.plotCanvas.getPlotType(plotName);
		if(type == Plot.CURVE)	
			return "Curve";
		else if(type == Plot.POINTS)
			return "Point";
		else if(type == Plot.CURVE_AND_POINTS)
			return "Curve and Point";
		else
			return "other";
	}

//
// Find the plot type given by a string,
// return the curve type if some other kind
//
	private int getPlotType()
	{
		String type = typeChoice.getSelectedItem();
		if(type.equals("Curve"))	
			return Plot.CURVE;
		else if(type.equals("Point"))
			return Plot.POINTS;
		else if(type.equals("Curve and Point"))
			return Plot.CURVE_AND_POINTS;
		else
			return Plot.CURVE;
	}


//
// Find the string that corresponds to the Color c,
// if not a "pre-defined color" from the Color class
// then it returns the String "other"
//
	private String getColorText(Color c)
	{
		if(c.equals(Color.black))
			return "black";
		else if(c.equals(Color.blue))
			return "blue";
		else if(c.equals(Color.cyan))
			return "cyan";
		else if(c.equals(Color.gray))
			return "gray";
		else if(c.equals(Color.green))
			return "green";
		else if(c.equals(Color.magenta))
			return "magenta";
		else if(c.equals(Color.orange))
			return "orange";
		else if(c.equals(Color.pink))
			return "pink";
		else if(c.equals(Color.red))
			return "red";
		else if(c.equals(Color.yellow))
			return "yellow";
		else if(c.equals(Color.white))
			return "white";
		else
			return "other";
	}

//
// Find the color that corresponds to the String,
// if not a "pre-defined color" from the Color class
// then it returns the Color black
//
	private Color getTextColor(String text)
	{
		if(text.equals("black"))
			return Color.black;
		else if(text.equals("blue"))
			return Color.blue;
		else if(text.equals("cyan"))
			return Color.cyan;
		else if(text.equals("gray"))
			return Color.gray;
		else if(text.equals("green"))
			return Color.green;
		else if(text.equals("magenta"))
			return Color.magenta;
		else if(text.equals("orange"))
			return Color.orange;
		else if(text.equals("pink"))
			return Color.pink;
		else if(text.equals("red"))
			return Color.red;
		else if(text.equals("yellow"))
			return Color.yellow;
		else if(text.equals("white"))
			return Color.white;
		else
			return Color.black;
	}
//
// Sets the values of plotName with data from
// fields
//
	private void setValues()
	{
		pFrame.plotCanvas.setPlotColor(plotName,getTextColor(colorChoice.getSelectedItem()));
		pFrame.plotCanvas.setPlotType(plotName,getPlotType());
		pFrame.plotCanvas.setPlotChar(plotName,(charText.getText().toCharArray())[0]);
		String newName = nameText.getText();
		// only change name values if the name has changed
		if(!newName.equals(plotName))
		{
			pFrame.plotCanvas.setPlotName(plotName,newName);
		//
		// Change the name in the menu for pFrame
		//
			for(int i=0;i<pFrame.CharacteristicsMenu.countItems();i++)
			{
				MenuItem mi = pFrame.CharacteristicsMenu.getItem(i);
				if(mi.getLabel().equals(plotName))
				{
					pFrame.CharacteristicsMenu.remove(mi);
 					mi.removeActionListener(pFrame.PlotCharAction);
 					mi = new MenuItem(newName);
					pFrame.CharacteristicsMenu.add(mi);
					mi.addActionListener(pFrame.PlotCharAction);
				}
			}
			setTitle("Plot: "+newName);
			plotName = newName;
		}
		pFrame.legend.validate();
		pFrame.legend.repaint();
       (pFrame.getPlot()).rePlot();
	}

   public synchronized void show() {
    	Rectangle bounds = getParent().bounds();
    	move(bounds.x + 50,bounds.y + 50);
    	super.show();
    }

	//{{DECLARE_CONTROLS
	java.awt.Label typeLabel;
	java.awt.Choice typeChoice;
	java.awt.Choice colorChoice;
	java.awt.Label colorLabel;
	java.awt.TextField charText;
	java.awt.Label charLabel;
	java.awt.TextField nameText;
	java.awt.Label nameLabel;
	java.awt.Button okButton;
	java.awt.Button applyButton;
	java.awt.Button cancelButton;
	java.awt.Button removeButton;
	//}}

class SymWindow extends java.awt.event.WindowAdapter
	{
		public void windowClosing(java.awt.event.WindowEvent event)
		{
			Object object = event.getSource();
			if (object == PlotInfoDialog.this)
				PlotInfoDialog_WindowClosing(event);
		}
	}
	
	void PlotInfoDialog_WindowClosing(java.awt.event.WindowEvent event)
	{
		setVisible(false);	
		dispose();
	}
	
	class SymAction implements java.awt.event.ActionListener
	{
		public void actionPerformed(java.awt.event.ActionEvent event)
		{
			Object object = event.getSource();
			if (object == removeButton)
				removeButton_ActionPerformed(event);
			else if (object == okButton)
				okButton_ActionPerformed(event);
			else if (object == applyButton)
				applyButton_ActionPerformed(event);
			else if (object == cancelButton)
				cancelButton_ActionPerformed(event);
		}
	}

	void removeButton_ActionPerformed(java.awt.event.ActionEvent event)
	{
 	   		// remove the plot
	   		pFrame.plotCanvas.removePlot(plotName);
	   		// remove the MenuItem
 			for(int i=0;i<pFrame.CharacteristicsMenu.countItems();i++)
			{
					MenuItem mi = pFrame.CharacteristicsMenu.getItem(i);
 					if(mi.getLabel().equals(plotName))
 					{
 					pFrame.CharacteristicsMenu.remove(mi);
 					mi.removeActionListener(pFrame.PlotCharAction);
 					}
 			}
			// remove the plot from the legend
		     pFrame.legend.removePlot();
             (pFrame.getPlot()).rePlot();
		     setVisible(false);
		     dispose();
  	}

	void colorChoice_MouseReleased(java.awt.event.MouseEvent event)
	{
	  setValues();
	}

	void okButton_ActionPerformed(java.awt.event.ActionEvent event)
	{
        setValues();
        setVisible(false);
        dispose();
	}

	void applyButton_ActionPerformed(java.awt.event.ActionEvent event)
	{
		 setValues();
	}

	void cancelButton_ActionPerformed(java.awt.event.ActionEvent event)
	{
		setVisible(false);
		dispose();
	}
}
